@@ -129,7 +129,7 @@ static const unsigned long _glibtop_sysdeps_fsusage =
 void
 _glibtop_linux_get_fsusage_read_write(glibtop *server,
 				      glibtop_fsusage *buf,
-				      const char *path) G_GNUC_INTERNAL;
+				      const char *path);
 
 static inline void
 _glibtop_get_fsusage_read_write(glibtop *server,
@@ -141,7 +141,7 @@ _glibtop_get_fsusage_read_write(glibtop *server,
 
 
 #elif defined(__FreeBSD__)
-void G_GNUC_INTERNAL
+void
 _glibtop_freebsd_get_fsusage_read_write(glibtop *server,
 					glibtop_fsusage *buf,
 					const char *path);
@@ -286,7 +286,7 @@ glibtop_get_fsusage_s (glibtop *server, glibtop_fsusage *buf,
 
   buf->blocks = fsd.f_blocks;
   buf->bfree  = fsd.f_bfree;
-  buf->bavail = fsd.f_bavail;
+  buf->bavail = (fsd.f_bavail > fsd.f_bfree) ? 0 : fsd.f_bavail;
   buf->files  = fsd.f_files;
   buf->ffree  = fsd.f_ffree;
 
