@@ -35,7 +35,7 @@ static const unsigned long _glibtop_sysdeps_uptime =
 /* Init function. */
 
 void
-glibtop_init_uptime_s (glibtop *server)
+_glibtop_init_uptime_s (glibtop *server)
 {
 	server->sysdeps.uptime = _glibtop_sysdeps_uptime;
 }
@@ -49,11 +49,9 @@ glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf)
 {
 	char buffer [BUFSIZ], *p;
 
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_UPTIME, 0);
-
 	memset (buf, 0, sizeof (glibtop_uptime));
 
-	file_to_buffer(server, buffer, FILENAME);
+	file_to_buffer(server, buffer, sizeof buffer, FILENAME);
 
 	buf->uptime   = g_ascii_strtod (buffer, &p);
 	buf->idletime = g_ascii_strtod (p, &p);
