@@ -1,5 +1,3 @@
-/* $Id: mem.c 2422 2005-12-12 09:38:15Z jamesh $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -30,7 +28,7 @@ static const unsigned long _glibtop_sysdeps_mem = 0;
 /* Init function. */
 
 void
-glibtop_init_mem_s (glibtop *server)
+_glibtop_init_mem_s (glibtop *server)
 {
 	server->sysdeps.mem = _glibtop_sysdeps_mem;
 }
